@@ -661,6 +661,15 @@ on_icon_view_item_activated (GtkIconView *icon_view,
   on_view_path_activated (self, path);
 }
 
+static void
+on_view_selection_changed (GtkWidget *view,
+                           gpointer user_data)
+{
+  GdMainView *self = user_data;
+
+  g_signal_emit (self, signals[VIEW_SELECTION_CHANGED], 0);
+}
+
 static void
 gd_main_view_apply_model (GdMainView *self)
 {
@@ -712,6 +721,8 @@ gd_main_view_rebuild (GdMainView *self)
                     G_CALLBACK (on_button_release_event), self);
   g_signal_connect_after (self->priv->current_view, "drag-begin",
                           G_CALLBACK (on_drag_begin), self);
+  g_signal_connect (self->priv->current_view, "view-selection-changed",
+                    G_CALLBACK (on_view_selection_changed), self);
 
   gd_main_view_apply_selection_mode (self);
   gd_main_view_apply_model (self);
@@ -849,39 +860,18 @@ gd_main_view_get_selection (GdMainView *self)
   return g_list_reverse (retval);
 }
 
-static gboolean
-set_selection_foreach (GtkTreeModel *model,
-                       GtkTreePath *path,
-                       GtkTreeIter *iter,
-                       gpointer user_data)
-{
-  gboolean selection = GPOINTER_TO_INT (user_data);
-
-  gtk_list_store_set (GTK_LIST_STORE (model), iter,
-                      GD_MAIN_COLUMN_SELECTED, selection,
-                      -1);
-
-  return FALSE;
-}
-
 void
 gd_main_view_select_all (GdMainView *self)
 {
-  gboolean selection = TRUE;
+  GdMainViewGeneric *generic = get_generic (self);
 
-  gtk_tree_model_foreach (self->priv->model,
-                          set_selection_foreach,
-                          GINT_TO_POINTER (selection));
-  g_signal_emit (self, signals[VIEW_SELECTION_CHANGED], 0);
+  gd_main_view_generic_select_all (generic);
 }
 
 void
 gd_main_view_unselect_all (GdMainView *self)
 {
-  gboolean selection = FALSE;
+  GdMainViewGeneric *generic = get_generic (self);
 
-  gtk_tree_model_foreach (self->priv->model,
-                          set_selection_foreach,
-                          GINT_TO_POINTER (selection));
-  g_signal_emit (self, signals[VIEW_SELECTION_CHANGED], 0);
+  gd_main_view_generic_unselect_all (generic);
 }
