@@ -23,11 +23,10 @@ const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 const Tweener = imports.util.tweener;
 
-const Global = imports.global;
+const Application = imports.application;
 const MainToolbar = imports.mainToolbar;
 const Notifications = imports.notifications;
 const Preview = imports.preview;
-const Searchbar = imports.searchbar;
 const Selections = imports.selections;
 const View = imports.view;
 const WindowMode = imports.windowMode;
@@ -70,7 +69,7 @@ const SpinnerBox = new Lang.Class({
                                           valign: Gtk.Align.CENTER });
         this.widget.add(this._spinner);
 
-        this._label = new Gtk.Label({ label: '<big><b>' + _("Loading...") + '</b></big>',
+        this._label = new Gtk.Label({ label: '<big><b>' + _("Loading…") + '</b></big>',
                                       use_markup: true,
                                       halign: Gtk.Align.CENTER,
                                       valign: Gtk.Align.CENTER });
@@ -227,7 +226,7 @@ const EmptyResultsBox = new Lang.Class({
                                          vexpand: true });
         this._labelsGrid.add(titleLabel);
 
-        if (Global.sourceManager.hasOnlineSources()) {
+        if (Application.sourceManager.hasOnlineSources()) {
             titleLabel.valign = Gtk.Align.CENTER;
         } else {
             titleLabel.valign = Gtk.Align.START;
@@ -363,59 +362,56 @@ const Embed = new Lang.Class({
         this._viewLayout.add(this._noResults.actor, Clutter.BinAlignment.FILL, Clutter.BinAlignment.FILL);
         this._noResults.actor.lower_bottom();
 
-        // also pack a white background to use for spotlights between window modes
-        this._background =
-            new Clutter.Rectangle({ color: new Clutter.Color ({ red: 255,
-                                                                blue: 255,
-                                                                green: 255,
-                                                                alpha: 255 }),
-                                    x_align: Clutter.ActorAlign.FILL,
-                                    x_expand: true,
-                                    y_align: Clutter.ActorAlign.FILL,
-                                    y_expand: true });
-        this._viewActor.insert_child_below(this._background, null);
-
         // create the OSD toolbar for selected items, it's hidden by default
         this._selectionToolbar = new Selections.SelectionToolbar(this._contentsActor);
         this._overlayLayout.add(this._selectionToolbar.actor,
             Clutter.BinAlignment.FIXED, Clutter.BinAlignment.FIXED);
 
         // pack the OSD notification actor
-        this._viewActor.add_child(Global.notificationManager.actor);
+        this._viewActor.add_child(Application.notificationManager.actor);
 
         // now create the actual content widgets
         this._view = new View.ViewContainer();
         this._viewPage = this._notebook.append_page(this._view.widget, null);
 
-        this._preview = new Preview.PreviewView();
+        this._preview = new Preview.PreviewView(this._overlayLayout);
         this._previewPage = this._notebook.append_page(this._preview.widget, null);
 
-        Global.modeController.connect('window-mode-changed',
-                                      Lang.bind(this, this._onWindowModeChanged));
-        Global.modeController.connect('fullscreen-changed',
-                                      Lang.bind(this, this._onFullscreenChanged));
-        Global.trackerController.connect('query-status-changed',
-                                         Lang.bind(this, this._onQueryStatusChanged));
-        Global.trackerController.connect('query-error',
-                                         Lang.bind(this, this._onQueryError));
+        Application.modeController.connect('window-mode-changed',
+                                           Lang.bind(this, this._onWindowModeChanged));
 
-        Global.offsetController.connect('item-count-changed',
+        Application.modeController.connect('fullscreen-changed',
+                                           Lang.bind(this, this._onFullscreenChanged));
+        Application.trackerController.connect('query-status-changed',
+                                              Lang.bind(this, this._onQueryStatusChanged));
+        Application.trackerController.connect('query-error',
+                                              Lang.bind(this, this._onQueryError));
+
+        Application.offsetController.connect('item-count-changed',
                                         Lang.bind(this, this._onItemCountChanged));
 
-        Global.documentManager.connect('active-changed',
-                                       Lang.bind(this, this._onActiveItemChanged));
-        Global.documentManager.connect('load-started',
-                                       Lang.bind(this, this._onLoadStarted));
-        Global.documentManager.connect('load-finished',
-                                       Lang.bind(this, this._onLoadFinished));
-        Global.documentManager.connect('load-error',
-                                       Lang.bind(this, this._onLoadError));
+        Application.documentManager.connect('active-changed',
+                                            Lang.bind(this, this._onActiveItemChanged));
+        Application.documentManager.connect('load-started',
+                                            Lang.bind(this, this._onLoadStarted));
+        Application.documentManager.connect('load-finished',
+                                            Lang.bind(this, this._onLoadFinished));
+        Application.documentManager.connect('load-error',
+                                            Lang.bind(this, this._onLoadError));
 
         this._onQueryStatusChanged();
+
+        let windowMode = Application.modeController.getWindowMode();
+        if (windowMode != WindowMode.WindowMode.NONE)
+            this._onWindowModeChanged(Application.modeController, windowMode, WindowMode.WindowMode.NONE);
     },
 
     _onQueryStatusChanged: function() {
-        let queryStatus = Global.trackerController.getQueryStatus();
+        let windowMode = Application.modeController.getWindowMode();
+        if (windowMode != WindowMode.WindowMode.OVERVIEW)
+            return;
+
+        let queryStatus = Application.trackerController.getQueryStatus();
 
         if (queryStatus) {
             this._errorBox.moveOut();
@@ -427,7 +423,7 @@ const Embed = new Lang.Class({
 
     _hideNoResultsPage: function() {
         if (this._noResultsChangeId != 0) {
-            Global.changeMonitor.disconnect(this._noResultsChangeId);
+            Application.changeMonitor.disconnect(this._noResultsChangeId);
             this._noResultsChangeId = 0;
         }
 
@@ -435,12 +431,12 @@ const Embed = new Lang.Class({
     },
 
     _onItemCountChanged: function() {
-        let itemCount = Global.offsetController.getItemCount();
+        let itemCount = Application.offsetController.getItemCount();
 
         if (itemCount == 0) {
             // also listen to changes-pending while in this mode
             this._noResultsChangeId =
-                Global.changeMonitor.connect('changes-pending', Lang.bind(this,
+                Application.changeMonitor.connect('changes-pending', Lang.bind(this,
                     function() {
                         this._hideNoResultsPage();
                     }));
@@ -456,32 +452,9 @@ const Embed = new Lang.Class({
     },
 
     _onFullscreenChanged: function(controller, fullscreen) {
-        if (fullscreen) {
-            this._previewFullscreen = new Preview.PreviewFullscreen(this._preview, this._overlayLayout, this._contentsActor);
-        } else {
-            this._previewFullscreen.destroy();
-            this._previewFullscreen = null;
-        }
-
         Gtk.Settings.get_default().gtk_application_prefer_dark_theme = fullscreen;
         this._toolbar.widget.visible = !fullscreen;
-    },
-
-    _moveOutBackground: function() {
-        Tweener.addTween(this._background, { opacity: 0,
-                                             time: 0.20,
-                                             transition: 'easeInQuad',
-                                             onComplete: function() {
-                                                 this._viewActor.set_child_below_sibling(this._background, null);
-                                             },
-                                             onCompleteScope: this });
-    },
-
-    _windowModeChangeFlash: function() {
-        // fade from white when returning to the view anyway
-        this._viewActor.set_child_above_sibling(this._background, null);
-        this._background.opacity = 255;
-        this._moveOutBackground();
+        this._toolbar.widget.sensitive = !fullscreen;
     },
 
     _onWindowModeChanged: function(object, newMode, oldMode) {
@@ -489,21 +462,18 @@ const Embed = new Lang.Class({
             this._prepareForOverview();
         else
             this._prepareForPreview();
-
-        if (oldMode != WindowMode.WindowMode.NONE)
-            this._windowModeChangeFlash();
     },
 
     _onActiveItemChanged: function(manager, doc) {
         let newMode = WindowMode.WindowMode.OVERVIEW;
 
         if (doc) {
-            let collection = Global.collectionManager.getItemById(doc.id);
+            let collection = Application.collectionManager.getItemById(doc.id);
             if (!collection)
                 newMode = WindowMode.WindowMode.PREVIEW;
         }
 
-        Global.modeController.setWindowMode(newMode);
+        Application.modeController.setWindowMode(newMode);
     },
 
     _onLoadStarted: function() {
@@ -518,7 +488,6 @@ const Embed = new Lang.Class({
         this._preview.widget.grab_focus();
 
         this._spinnerBox.moveOut();
-        Global.modeController.setCanFullscreen(true);
     },
 
     _onLoadError: function(manager, doc, message, exception) {
@@ -563,7 +532,11 @@ const Embed = new Lang.Class({
         this._errorBox.moveIn();
     },
 
-    getMainToolbar: function(event) {
+    getMainToolbar: function() {
         return this._toolbar;
+    },
+
+    getPreview: function() {
+        return this._preview;
     }
 });
