@@ -30,11 +30,13 @@ const _ = imports.gettext.gettext;
 
 const Lang = imports.lang;
 const Mainloop = imports.mainloop;
+const Signals = imports.signals;
 
-const Global = imports.global;
+const Application = imports.application;
 const Tweener = imports.util.tweener;
 const MainToolbar = imports.mainToolbar;
 const Searchbar = imports.searchbar;
+const Utils = imports.utils;
 const View = imports.view;
 
 const _FULLSCREEN_TOOLBAR_TIMEOUT = 2; // seconds
@@ -42,49 +44,75 @@ const _FULLSCREEN_TOOLBAR_TIMEOUT = 2; // seconds
 const PreviewView = new Lang.Class({
     Name: 'PreviewView',
 
-    _init: function() {
+    _init: function(overlayLayout) {
         this._model = null;
         this._jobFind = null;
+        this._controlsFlipId = 0;
+        this._controlsVisible = false;
+        this._selectionChanged = false;
+
+        Application.modeController.connect('fullscreen-changed',
+            Lang.bind(this, this._onFullscreenChanged));
 
         this.widget = new Gtk.ScrolledWindow({ hexpand: true,
                                                vexpand: true,
                                                shadow_type: Gtk.ShadowType.IN });
         this.widget.get_style_context().add_class('documents-scrolledwin');
+        this.widget.get_hscrollbar().connect('button-press-event', Lang.bind(this, this._onScrollbarClick));
+        this.widget.get_vscrollbar().connect('button-press-event', Lang.bind(this, this._onScrollbarClick));
+        this.widget.get_hadjustment().connect('value-changed', Lang.bind(this, this._onAdjustmentChanged));
+        this.widget.get_vadjustment().connect('value-changed', Lang.bind(this, this._onAdjustmentChanged));
 
         this._createView();
+
+        // create thumb bar
+        this._thumbBar = new PreviewThumbnails(this._model);
+        overlayLayout.add(this._thumbBar.actor,
+            Clutter.BinAlignment.FILL, Clutter.BinAlignment.END);
+        this._thumbBar.view.connect('selection-changed', Lang.bind(this,
+            function() {
+                this._selectionChanged = true;
+            }));
+
+        // create fullscreen toolbar (hidden by default)
+        this._fsToolbar = new PreviewFullscreenToolbar(this);
+        this._fsToolbar.setModel(this._model);
+        overlayLayout.add(this._fsToolbar.actor,
+            Clutter.BinAlignment.FILL, Clutter.BinAlignment.START);
+
         this.widget.show_all();
 
-        this._zoomIn = Global.application.lookup_action('zoom-in');
+        this._zoomIn = Application.application.lookup_action('zoom-in');
         this._zoomIn.connect('activate', Lang.bind(this,
             function() {
                 this._model.set_sizing_mode(EvView.SizingMode.FREE);
                 this.view.zoom_in();
             }));
 
-        this._zoomOut = Global.application.lookup_action('zoom-out');
+        this._zoomOut = Application.application.lookup_action('zoom-out');
         this._zoomOut.connect('activate', Lang.bind(this,
             function() {
                 this._model.set_sizing_mode(EvView.SizingMode.FREE);
                 this.view.zoom_out();
             }));
 
-        this._findPrev = Global.application.lookup_action('find-prev');
+        this._findPrev = Application.application.lookup_action('find-prev');
         this._findPrev.connect('activate', Lang.bind(this,
             function() {
                 this.view.find_previous();
             }));
-        this._findNext = Global.application.lookup_action('find-next');
+        this._findNext = Application.application.lookup_action('find-next');
         this._findNext.connect('activate', Lang.bind(this,
             function() {
                 this.view.find_next();
             }));
 
-        let rotLeft = Global.application.lookup_action('rotate-left');
+        let rotLeft = Application.application.lookup_action('rotate-left');
         rotLeft.connect('activate', Lang.bind(this,
             function() {
                 this._changeRotation(-90);
             }));
-        let rotRight = Global.application.lookup_action('rotate-right');
+        let rotRight = Application.application.lookup_action('rotate-right');
         rotRight.connect('activate', Lang.bind(this,
             function() {
                 this._changeRotation(90);
@@ -96,12 +124,45 @@ const PreviewView = new Lang.Class({
         this.widget.add(this.view);
         this.view.show();
 
-        this.view.connect('button-press-event',
-                            Lang.bind(this, this._onButtonPressEvent));
+        this.view.connect('button-release-event',
+                            Lang.bind(this, this._onButtonReleaseEvent));
         this.view.connect('key-press-event',
                             Lang.bind(this, this._onKeyPressEvent));
     },
 
+    _updateControls: function(visible) {
+        if (this._controlsVisible == visible)
+            return;
+
+        this._controlsVisible = visible;
+
+        if (this._controlsVisible) {
+            if (Application.modeController.getFullscreen())
+                this._fsToolbar.show();
+            this._thumbBar.show();
+        } else {
+            this._fsToolbar.hide();
+            this._thumbBar.hide();
+        }
+    },
+
+    _flipControlsState: function() {
+        this._controlsFlipId = 0;
+        let visible = !this._controlsVisible;
+        this._updateControls(visible);
+
+        return false;
+    },
+
+    _onFullscreenChanged: function() {
+        let fullscreen = Application.modeController.getFullscreen();
+
+        if (fullscreen && this._controlsVisible)
+            this._fsToolbar.show();
+        else if (!fullscreen)
+            this._fsToolbar.hide();
+    },
+
     _onKeyPressEvent: function(widget, event) {
         let keyval = event.get_keyval()[1];
         let state = event.get_state()[1];
@@ -132,23 +193,61 @@ const PreviewView = new Lang.Class({
         return false;
      },
 
-    _onButtonPressEvent: function(widget, event) {
+     _cancelControlsFlip: function() {
+         if (this._controlsFlipId != 0) {
+             Mainloop.source_remove(this._controlsFlipId);
+             this._controlsFlipId = 0;
+         }
+     },
+
+     _ensureControlsFlip: function() {
+         if (this._controlsFlipId)
+             return;
+
+         let settings = Gtk.Settings.get_default();
+         let doubleClick = settings.gtk_double_click_time;
+
+         this._controlsFlipId = Mainloop.timeout_add(doubleClick, Lang.bind(this, this._flipControlsState));
+     },
+
+    _onButtonReleaseEvent: function(widget, event) {
         let button = event.get_button()[1];
         let clickCount = event.get_click_count()[1];
 
-        if (button == 1 && clickCount == 2) {
-            Global.modeController.toggleFullscreen();
-            return true;
-        }
+        if (button == 1 && clickCount == 1)
+            this._ensureControlsFlip();
+        else
+            this._cancelControlsFlip();
 
         return false;
     },
 
+    _onScrollbarClick: function() {
+        if (this._controlsVisible)
+            this._flipControlsState();
+
+        return false;
+    },
+
+    _onAdjustmentChanged: function() {
+        if (this._controlsVisible && !this._selectionChanged)
+            this._flipControlsState();
+        this._selectionChanged = false;
+    },
+
     _changeRotation: function(offset) {
         let rotation = this._model.get_rotation();
         this._model.set_rotation(rotation + offset);
     },
 
+    get controlsVisible() {
+        return this._controlsVisible;
+    },
+
+    set controlsVisible(visible) {
+        this._updateControls(visible);
+    },
+
     startSearch: function(str) {
         if (!this._model)
             return;
@@ -176,20 +275,26 @@ const PreviewView = new Lang.Class({
         // FIXME: ev_job_find_get_results() returns a GList **
         // and thus is not introspectable
         GdPrivate.ev_view_find_changed(this.view, job, page);
+        this.emit('search-changed', job.has_results());
     },
 
     setModel: function(model) {
         if (this._model == model)
             return;
 
-        if (this.view)
+        if (this.view) {
             this.view.destroy();
+            this._thumbBar.hide();
+            this._fsToolbar.hide();
+        }
 
         this._model = model;
 
         if (this._model) {
             this._createView();
             this.view.set_model(this._model);
+            this._thumbBar.view.model = model;
+            this._fsToolbar.setModel(model);
         }
     },
 
@@ -197,17 +302,23 @@ const PreviewView = new Lang.Class({
         return this._model;
     }
 });
+Signals.addSignalMethods(PreviewView.prototype);
 
 const PreviewThumbnails = new Lang.Class({
     Name: 'PreviewThumbnails',
 
     _init: function(model) {
-        this.view = new GdPrivate.SidebarThumbnails({ model: model });
-        this.widget = new GdPrivate.ThumbNav({ thumbview: this.view });
+        this.view = new GdPrivate.SidebarThumbnails({ model: model,
+                                                      visible: true });
+        this.widget = new GdPrivate.ThumbNav({ thumbview: this.view,
+                                               show_buttons: false });
+        this.widget.get_style_context().add_class('osd');
         this.actor = new GtkClutter.Actor({ contents: this.widget,
+                                            visible: false,
                                             opacity: 0 });
+        Utils.alphaGtkWidget(this.actor.get_widget());
 
-        this.widget.show_all();
+        this.widget.show();
     },
 
     show: function() {
@@ -231,121 +342,6 @@ const PreviewThumbnails = new Lang.Class({
     }
 });
 
-const PreviewFullscreen = new Lang.Class({
-    Name: 'PreviewFullscreen',
-
-    _init: function(previewView, layout, parentActor) {
-        this._motionTimeoutId = 0;
-
-        let model = previewView.getModel();
-
-        this._filter = new GdPrivate.FullscreenFilter();
-        this._filter.connect('motion-event', Lang.bind(this, this._fullscreenMotionHandler));
-        this._filter.start();
-
-        // create thumb bar
-        this._thumbBar = new PreviewThumbnails(model);
-
-        layout.add(this._thumbBar.actor,
-            Clutter.BinAlignment.FIXED, Clutter.BinAlignment.FIXED);
-
-        let widthConstraint =
-            new Clutter.BindConstraint({ source: parentActor,
-                                         coordinate: Clutter.BindCoordinate.WIDTH,
-                                         offset: - 300 });
-        this._thumbBar.actor.add_constraint(widthConstraint);
-        this._thumbBar.actor.connect('notify::width', Lang.bind(this,
-            function() {
-                let width = parentActor.width;
-                let offset = 300;
-
-                if (width > 1000)
-                    offset += (width - 1000);
-                else if (width < 600)
-                    offset -= (600 - width);
-
-                widthConstraint.offset = - offset;
-            }));
-
-        this._thumbBar.actor.add_constraint(
-            new Clutter.AlignConstraint({ align_axis: Clutter.AlignAxis.X_AXIS,
-                                          source: parentActor,
-                                          factor: 0.50 }));
-        this._thumbBar.actor.add_constraint(
-            new Clutter.AlignConstraint({ align_axis: Clutter.AlignAxis.Y_AXIS,
-                                          source: parentActor,
-                                          factor: 0.95 }));
-
-        // create toolbar
-        this._fsToolbar = new PreviewFullscreenToolbar(previewView);
-        this._fsToolbar.setModel(model);
-
-        layout.add(this._fsToolbar.actor,
-            Clutter.BinAlignment.FIXED, Clutter.BinAlignment.FIXED);
-
-        let vScrollbar = previewView.widget.get_vscrollbar();
-
-        let sizeConstraint = new Clutter.BindConstraint
-            ({ coordinate: Clutter.BindCoordinate.WIDTH,
-               source: parentActor,
-               offset: (vScrollbar.get_visible() ?
-                        (- (vScrollbar.get_preferred_width()[1])) : 0 ) });
-
-        // update the constraint size when the scrollbar changes visibility
-        vScrollbar.connect('notify::visible',
-            function() {
-                sizeConstraint.offset = (vScrollbar.get_visible() ?
-                                         (- (vScrollbar.get_preferred_width()[1])) : 0 );
-            });
-
-        this._fsToolbar.actor.add_constraint(sizeConstraint);
-    },
-
-    destroy: function() {
-        if (this._motionTimeoutId != 0) {
-            Mainloop.source_remove(this._motionTimeoutId);
-            this._motionTimeoutId = 0;
-        }
-
-        this._filter.stop();
-
-        this._thumbBar.actor.destroy();
-        this._fsToolbar.actor.destroy();
-    },
-
-    _show: function() {
-        this._fsToolbar.show();
-        this._thumbBar.show();
-    },
-
-    _hide: function() {
-        this._fsToolbar.hide();
-        this._thumbBar.hide();
-    },
-
-    _fullscreenMotionHandler: function() {
-        if (!Global.modeController.getFullscreen())
-            return;
-
-        // if we were idle fade in the toolbar, otherwise reset
-        // the timeout
-        if (this._motionTimeoutId == 0) {
-            this._show();
-        } else {
-            Mainloop.source_remove(this._motionTimeoutId);
-        }
-
-        this._motionTimeoutId = Mainloop.timeout_add_seconds
-            (_FULLSCREEN_TOOLBAR_TIMEOUT, Lang.bind(this,
-                function() {
-                    this._motionTimeoutId = 0;
-                    this._hide();
-
-                    return false;
-            }));
-    }
-});
-
 const PreviewToolbar = new Lang.Class({
     Name: 'PreviewToolbar',
     Extends: MainToolbar.MainToolbar,
@@ -363,7 +359,7 @@ const PreviewToolbar = new Lang.Class({
             this.widget.add_button(iconName, _("Back"), true);
         backButton.connect('clicked', Lang.bind(this,
             function() {
-                Global.documentManager.setActiveItem(null);
+                Application.documentManager.setActiveItem(null);
             }));
 
         // search button, on the right of the toolbar
@@ -384,7 +380,7 @@ const PreviewToolbar = new Lang.Class({
         builder.add_from_resource('/org/gnome/documents/preview-menu.ui');
         let menu = builder.get_object('preview-menu');
 
-        let doc = Global.documentManager.getActiveItem();
+        let doc = Application.documentManager.getActiveItem();
         if (doc && doc.defaultAppName) {
             let section = builder.get_object('open-section');
             section.remove(0);
@@ -403,25 +399,12 @@ const PreviewToolbar = new Lang.Class({
 
     _setToolbarTitle: function() {
         let primary = null;
-        let detail = null;
-        let doc = Global.documentManager.getActiveItem();
+        let doc = Application.documentManager.getActiveItem();
 
         if (doc)
             primary = doc.name;
 
-        if (this._model) {
-            let curPage, totPages;
-
-            curPage = this._model.get_page();
-            totPages = this._model.get_document().get_n_pages();
-
-            detail = _("%d of %d").format(curPage + 1, totPages);
-        }
-
-        if (detail)
-            detail = '(' + detail + ')';
-
-        this.widget.set_labels(primary, detail);
+        this.widget.set_labels(primary, null);
     },
 
     setModel: function(model) {
@@ -429,11 +412,6 @@ const PreviewToolbar = new Lang.Class({
             return;
 
         this._model = model;
-        this._model.connect('page-changed', Lang.bind(this,
-            function() {
-                this._setToolbarTitle();
-            }));
-
         this._setToolbarTitle();
     }
 });
@@ -443,9 +421,11 @@ const PreviewSearchbar = new Lang.Class({
     Extends: Searchbar.Searchbar,
 
     _init: function(previewView) {
-        this.parent();
-
         this._previewView = previewView;
+        this._previewView.connect('search-changed', Lang.bind(this, this._onSearchChanged));
+        this._lastText = '';
+
+        this.parent();
     },
 
     createSearchWidgets: function() {
@@ -456,7 +436,7 @@ const PreviewSearchbar = new Lang.Class({
         this._searchEntry = new Gtk.SearchEntry({ width_request: 500 });
         this._searchEntry.connect('activate', Lang.bind(this,
             function() {
-                Global.application.activate_action('find-next', null);
+                Application.application.activate_action('find-next', null);
             }));
         this._searchContainer.add(this._searchEntry);
 
@@ -465,19 +445,28 @@ const PreviewSearchbar = new Lang.Class({
         controlsBox.get_style_context().add_class('raised');
         this._searchContainer.add(controlsBox);
 
-        let prev = new Gtk.Button({ action_name: 'app.find-prev' });
-        prev.set_image(new Gtk.Image({ icon_name: 'go-up-symbolic',
-                                       icon_size: Gtk.IconSize.MENU,
-                                       margin: 2 }));
-        prev.set_tooltip_text(_("Find Previous"));
-        controlsBox.add(prev);
+        this._prev = new Gtk.Button({ action_name: 'app.find-prev' });
+        this._prev.set_image(new Gtk.Image({ icon_name: 'go-up-symbolic',
+                                             icon_size: Gtk.IconSize.MENU,
+                                             margin: 2 }));
+        this._prev.set_tooltip_text(_("Find Previous"));
+        controlsBox.add(this._prev);
 
-        let next = new Gtk.Button({ action_name: 'app.find-next' });
-        next.set_image(new Gtk.Image({ icon_name: 'go-down-symbolic',
-                                       icon_size: Gtk.IconSize.MENU,
-                                       margin: 2 }));
-        next.set_tooltip_text(_("Find Next"));
-        controlsBox.add(next);
+        this._next = new Gtk.Button({ action_name: 'app.find-next' });
+        this._next.set_image(new Gtk.Image({ icon_name: 'go-down-symbolic',
+                                             icon_size: Gtk.IconSize.MENU,
+                                             margin: 2 }));
+        this._next.set_tooltip_text(_("Find Next"));
+        controlsBox.add(this._next);
+
+        this._onSearchChanged(this._previewView, false);
+    },
+
+    _onSearchChanged: function(view, hasResults) {
+        let findPrev = Application.application.lookup_action('find-prev');
+        let findNext = Application.application.lookup_action('find-next');
+        findPrev.enabled = hasResults;
+        findNext.enabled = hasResults;
     },
 
     entryChanged: function() {
@@ -488,15 +477,21 @@ const PreviewSearchbar = new Lang.Class({
     show: function() {
         this.parent();
 
-        this._searchEntry.select_region(0, -1);
+        if (!this._searchEntry.get_text()) {
+            this._searchEntry.set_text(this._lastText);
+            this._searchEntry.select_region(0, -1);
+        }
+
+        this._lastText = '';
         this._previewView.view.find_set_highlight_search(true);
         this._previewView.startSearch(this._searchEntry.get_text());
     },
 
     hide: function() {
-        this.parent();
-
         this._previewView.view.find_set_highlight_search(false);
+        this._lastText = this._searchEntry.get_text();
+
+        this.parent();
     }
 });
 
@@ -507,20 +502,29 @@ const PreviewFullscreenToolbar = new Lang.Class({
     _init: function(previewView) {
         this.parent(previewView);
 
-        this.actor.y = -(this.widget.get_preferred_height()[1]);
+        this.actor.visible = false;
+        this.widget.sensitive = false;
+        this.actor.translation_y = -(this.widget.get_preferred_height()[1]);
     },
 
     show: function() {
+        this.actor.show();
+        this.widget.sensitive = true;
         Tweener.addTween(this.actor,
-                         { y: 0,
+                         { translation_y: 0,
                            time: 0.20,
                            transition: 'easeInQuad' });
     },
 
     hide: function() {
         Tweener.addTween(this.actor,
-                         { y: -(this.widget.get_preferred_height()[1]),
+                         { translation_y: -(this.widget.get_preferred_height()[1]),
                            time: 0.20,
-                           transition: 'easeOutQuad' });
+                           transition: 'easeOutQuad',
+                           onComplete: function() {
+                               this.actor.hide();
+                               this.widget.sensitive = false;
+                           },
+                           onCompleteScope: this });
     }
 });
