@@ -31,248 +31,13 @@ const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 const Signals = imports.signals;
 
-const Global = imports.global;
+const Application = imports.application;
 const Manager = imports.manager;
-const Sources = imports.sources;
 const Tweener = imports.util.tweener;
 const Utils = imports.utils;
 
 const _SEARCH_ENTRY_TIMEOUT = 200;
 
-const SearchCategoryStock = {
-    ALL: 'all',
-    FAVORITES: 'favorites',
-    SHARED: 'shared',
-    PRIVATE: 'private'
-};
-
-const SearchCategory = new Lang.Class({
-    Name: 'SearchCategory',
-
-    _init: function(params) {
-        this.id = params.id;
-        this.name = params.name;
-        this.icon = params.icon;
-    },
-
-    getWhere: function() {
-        if (this.id == SearchCategoryStock.FAVORITES)
-            return '{ ?urn nao:hasTag nao:predefined-tag-favorite }';
-
-        // require to have a contributor, and creator, and they should be different
-        if (this.id == SearchCategoryStock.SHARED)
-            return '{ ?urn nco:contributor ?contributor . ?urn nco:creator ?creator FILTER (?contributor != ?creator ) }';
-
-        return '';
-    },
-
-    getFilter: function() {
-        // require to be not local
-        if (this.id == SearchCategoryStock.SHARED)
-            return Global.queryBuilder.buildFilterNotLocal();
-
-        return '(true)';
-    }
-});
-
-const SearchCategoryManager = new Lang.Class({
-    Name: 'SearchCategoryManager',
-    Extends: Manager.BaseManager,
-
-    _init: function() {
-        this.parent(_("Category"));
-
-        let category, recent;
-        // Translators: this refers to new and recent documents
-        recent = new SearchCategory({ id: SearchCategoryStock.ALL,
-                                      name: _("All"),
-                                      icon: '' });
-        this.addItem(recent);
-
-        // Translators: this refers to favorite documents
-        category = new SearchCategory({ id: SearchCategoryStock.FAVORITES,
-                                        name: _("Favorites"),
-                                        icon: 'emblem-favorite-symbolic' });
-        this.addItem(category);
-        // Translators: this refers to shared documents
-        category = new SearchCategory({ id: SearchCategoryStock.SHARED,
-                                        name: _("Shared with you"),
-                                        icon: 'emblem-shared-symbolic' });
-        this.addItem(category);
-
-        // Private category: currently unimplemented
-        // category = new SearchCategory(SearchCategoryStock.PRIVATE, _("Private"), 'channel-secure-symbolic');
-        // this._categories[category.id] = category;
-
-        this.setActiveItem(recent);
-    }
-});
-
-const SearchType = new Lang.Class({
-    Name: 'SearchType',
-
-    _init: function(params) {
-        this.id = params.id;
-        this.name = params.name;
-        this._filter = (params.filter) ? (params.filter) : '(true)';
-        this._where = (params.where) ? (params.where) : '';
-    },
-
-    getFilter: function() {
-        return this._filter;
-    },
-
-    getWhere: function() {
-        return this._where;
-    }
-});
-
-const SearchTypeManager = new Lang.Class({
-    Name: 'SearchTypeManager',
-    Extends: Manager.BaseManager,
-
-    _init: function() {
-        // Translators: "Type" refers to a search filter on the document type
-        // (PDF, spreadsheet, ...)
-        this.parent(_("Type"));
-
-        this.addItem(new SearchType({ id: 'all',
-                                      name: _("All") }));
-        this.addItem(new SearchType({ id: 'collections',
-                                      name: _("Collections"),
-                                      filter: 'fn:starts-with(nao:identifier(?urn), \"gd:collection\")',
-                                      where: '?urn rdf:type nfo:DataContainer .' }));
-        this.addItem(new SearchType({ id: 'pdf',
-                                      name: _("PDF Documents"),
-                                      filter: 'fn:contains(nie:mimeType(?urn), \"application/pdf\")',
-                                      where: '?urn rdf:type nfo:PaginatedTextDocument .' }));
-        this.addItem(new SearchType({ id: 'presentations',
-                                      name: _("Presentations"),
-                                      where: '?urn rdf:type nfo:Presentation .' }));
-        this.addItem(new SearchType({ id: 'spreadsheets',
-                                      name: _("Spreadsheets"),
-                                      where: '?urn rdf:type nfo:Spreadsheet .' }));
-        this.addItem(new SearchType({ id: 'textdocs',
-                                      name: _("Text Documents"),
-                                      where: '?urn rdf:type nfo:PaginatedTextDocument .' }));
-
-        this.setActiveItemById('all');
-    },
-
-    getCurrentTypes: function() {
-        let activeItem = this.getActiveItem();
-
-        if (activeItem.id == 'all')
-            return this.getAllTypes();
-
-        return [ activeItem ];
-    },
-
-    getAllTypes: function() {
-        let types = [];
-
-        this.forEachItem(function(item) {
-            if (item.id != 'all')
-                types.push(item);
-            });
-
-        return types;
-    }
-});
-
-const SearchMatchStock = {
-    ALL: 'all',
-    TITLE: 'title',
-    AUTHOR: 'author'
-};
-
-const SearchMatch = new Lang.Class({
-    Name: 'SearchMatch',
-
-    _init: function(params) {
-        this.id = params.id;
-        this.name = params.name;
-        this._term = '';
-    },
-
-    setFilterTerm: function(term) {
-        this._term = term;
-    },
-
-    getFilter: function() {
-        if (this.id == SearchMatchStock.TITLE)
-            return ('fn:contains ' +
-                    '(fn:lower-case (tracker:coalesce(nie:title(?urn), nfo:fileName(?urn))), ' +
-                    '"%s")').format(this._term);
-        if (this.id == SearchMatchStock.AUTHOR)
-            return ('fn:contains ' +
-                    '(fn:lower-case (tracker:coalesce(nco:fullname(?creator), nco:fullname(?publisher))), ' +
-                    '"%s")').format(this._term);
-        return '';
-    }
-});
-
-const SearchMatchManager = new Lang.Class({
-    Name: 'SearchMatchManager',
-    Extends: Manager.BaseManager,
-
-    _init: function() {
-        // Translators: this is a verb that refers to "All", "Title" and "Author",
-        // as in "Match All", "Match Title" and "Match Author"
-        this.parent(_("Match"));
-
-        this.addItem(new SearchMatch({ id: SearchMatchStock.ALL,
-                                       name: _("All") }));
-        this.addItem(new SearchMatch({ id: SearchMatchStock.TITLE,
-        //Translators: "Title" refers to "Match Title" when searching
-                                       name: _("Title") }));
-        this.addItem(new SearchMatch({ id: SearchMatchStock.AUTHOR,
-        //Translators: "Author" refers to "Match Author" when searching
-                                       name: _("Author") }));
-
-        this.setActiveItemById(SearchMatchStock.ALL);
-    },
-
-    getFilter: function() {
-        let terms = Global.searchController.getTerms();
-        let filters = [];
-
-        for (let i = 0; i < terms.length; i++) {
-            this.forEachItem(function(item) {
-                item.setFilterTerm(terms[i]);
-            });
-            filters.push(this.parent());
-        }
-        return filters.length ? '( ' + filters.join(' && ') + ')' : '';
-    }
-});
-
-const SearchController = new Lang.Class({
-    Name: 'SearchController',
-
-    _init: function() {
-        this._string = '';
-    },
-
-    setString: function(string) {
-        if (this._string == string)
-            return;
-
-        this._string = string;
-        this.emit('search-string-changed', this._string);
-    },
-
-    getString: function() {
-        return this._string;
-    },
-
-    getTerms: function() {
-        let str = Tracker.sparql_escape_string(this._string);
-        return str.replace(/ +/g, ' ').split(' ');
-    }
-});
-Signals.addSignalMethods(SearchController.prototype);
-
 const Searchbar = new Lang.Class({
     Name: 'Searchbar',
 
@@ -303,7 +68,7 @@ const Searchbar = new Lang.Class({
                 let keyval = event.get_keyval()[1];
 
                 if (keyval == Gdk.KEY_Escape) {
-                    Global.application.change_action_state('search', GLib.Variant.new('b', false));
+                    Application.application.change_action_state('search', GLib.Variant.new('b', false));
                     return true;
                 }
 
@@ -325,22 +90,34 @@ const Searchbar = new Lang.Class({
             }));
 
         // connect to the search action state for visibility
-        let searchStateId = Global.application.connect('action-state-changed::search', Lang.bind(this,
-            function(source, actionName, state) {
-                if (state.get_boolean())
-                    this.show();
-                else
-                    this.hide();
+        let searchStateId = Application.application.connect('action-state-changed::search',
+            Lang.bind(this, this._onActionStateChanged));
+        this._onActionStateChanged(Application.application, 'search', Application.application.get_action_state('search'));
+
+        // connect to search string changes in the controller
+        this._searchEntry.text = Application.searchController.getString();
+        let searchChangedId = Application.searchController.connect('search-string-changed', Lang.bind(this,
+            function(controller, string) {
+                this._searchEntry.text = string;
             }));
+
         this.widget.connect('destroy', Lang.bind(this,
             function() {
-                Global.application.disconnect(searchStateId);
-                Global.application.change_action_state('search', GLib.Variant.new('b', false));
+                Application.searchController.disconnect(searchChangedId);
+                Application.application.disconnect(searchStateId);
+                Application.application.change_action_state('search', GLib.Variant.new('b', false));
             }));
 
         this.widget.show_all();
     },
 
+    _onActionStateChanged: function(source, actionName, state) {
+        if (state.get_boolean())
+            this.show();
+        else
+            this.hide();
+    },
+
     createSearchWidgets: function() {
         log('Error: Searchbar implementations must override createSearchWidgets');
     },
@@ -419,7 +196,7 @@ const Searchbar = new Lang.Class({
             handled = true;
 
             if (!this._in)
-                Global.application.change_action_state('search', GLib.Variant.new('b', true));
+                Application.application.change_action_state('search', GLib.Variant.new('b', true));
         }
 
         return handled;
@@ -434,7 +211,8 @@ const Searchbar = new Lang.Class({
                                        transition: 'easeOutQuad',
                                        onComplete: function() {
                                            this._in = true;
-                                           Gd.entry_focus_hack(this._searchEntry, eventDevice);
+                                           if (eventDevice)
+                                               Gd.entry_focus_hack(this._searchEntry, eventDevice);
                                        },
                                        onCompleteScope: this });
     },
@@ -446,6 +224,9 @@ const Searchbar = new Lang.Class({
                                        onComplete: function() {
                                            this._searchEntry.hide();
                                            this._in = false;
+
+                                           // clear all the search properties when hiding the entry
+                                           this._searchEntry.set_text('');
                                        },
                                        onCompleteScope: this });
     }
@@ -455,12 +236,12 @@ const Dropdown = new Lang.Class({
     Name: 'Dropdown',
 
     _init: function() {
-        this._sourceView = new Manager.BaseView(Global.sourceManager);
-        this._typeView = new Manager.BaseView(Global.searchTypeManager);
-        this._matchView = new Manager.BaseView(Global.searchMatchManager);
+        this._sourceView = new Manager.BaseView(Application.sourceManager);
+        this._typeView = new Manager.BaseView(Application.searchTypeManager);
+        this._matchView = new Manager.BaseView(Application.searchMatchManager);
         // TODO: this is out for now, but should we move it somewhere
         // else?
-        // this._categoryView = new Manager.BaseView(Global.searchCategoryManager);
+        // this._categoryView = new Manager.BaseView(Application.searchCategoryManager);
 
         this._sourceView.connect('item-activated',
                                  Lang.bind(this, this._onItemActivated));
@@ -524,13 +305,13 @@ const OverviewSearchbar = new Lang.Class({
 
         this.parent();
 
-        this._sourcesId = Global.sourceManager.connect('active-changed',
+        this._sourcesId = Application.sourceManager.connect('active-changed',
             Lang.bind(this, this._onActiveSourceChanged));
-        this._searchTypeId = Global.searchTypeManager.connect('active-changed',
+        this._searchTypeId = Application.searchTypeManager.connect('active-changed',
             Lang.bind(this, this._onActiveTypeChanged));
-        this._searchMatchId = Global.searchMatchManager.connect('active-changed',
+        this._searchMatchId = Application.searchMatchManager.connect('active-changed',
             Lang.bind(this, this._onActiveMatchChanged));
-        this._collectionId = Global.collectionManager.connect('active-changed',
+        this._collectionId = Application.collectionManager.connect('active-changed',
             Lang.bind(this, this._onActiveCollectionChanged));
 
         this._onActiveSourceChanged();
@@ -540,11 +321,10 @@ const OverviewSearchbar = new Lang.Class({
 
     createSearchWidgets: function() {
         // create the search entry
-        this._searchEntry = new Gd.TaggedEntry({ width_request: 500,
-                                                 no_show_all: true });
+        this._searchEntry = new Gd.TaggedEntry({ width_request: 500 });
         this._searchEntry.connect('tag-clicked',
             Lang.bind(this, this._onTagClicked));
-        this._searchEntry.set_text(Global.searchController.getString());
+        this._searchEntry.set_text(Application.searchController.getString());
 
         // create the dropdown button
         this._dropdownButton = new Gtk.ToggleButton(
@@ -572,15 +352,15 @@ const OverviewSearchbar = new Lang.Class({
 
     entryChanged: function() {
         let currentText = this._searchEntry.get_text().toLowerCase();
-        Global.searchController.setString(currentText);
+        Application.searchController.setString(currentText);
     },
 
     _onActiveCollectionChanged: function() {
-        let searchType = Global.searchTypeManager.getActiveItem();
+        let searchType = Application.searchTypeManager.getActiveItem();
 
-        if (Global.searchController.getString() != '' ||
+        if (Application.searchController.getString() != '' ||
             searchType.id != 'all') {
-            Global.searchTypeManager.setActiveItemById('all');
+            Application.searchTypeManager.setActiveItemById('all');
             this._searchEntry.set_text('');
         }
     },
@@ -605,15 +385,15 @@ const OverviewSearchbar = new Lang.Class({
     },
 
     _onActiveSourceChanged: function() {
-        this._onActiveChangedCommon('source', Global.sourceManager);
+        this._onActiveChangedCommon('source', Application.sourceManager);
     },
 
     _onActiveTypeChanged: function() {
-        this._onActiveChangedCommon('type', Global.searchTypeManager);
+        this._onActiveChangedCommon('type', Application.searchTypeManager);
     },
 
     _onActiveMatchChanged: function() {
-        this._onActiveChangedCommon('match', Global.searchMatchManager);
+        this._onActiveChangedCommon('match', Application.searchMatchManager);
     },
 
     _onTagClicked: function() {
@@ -622,22 +402,22 @@ const OverviewSearchbar = new Lang.Class({
 
     destroy: function() {
         if (this._sourcesId != 0) {
-            Global.sourceManager.disconnect(this._sourcesId);
+            Application.sourceManager.disconnect(this._sourcesId);
             this._sourcesId = 0;
         }
 
         if (this._searchTypeId != 0) {
-            Global.searchTypeManager.disconnect(this._searchTypeId);
+            Application.searchTypeManager.disconnect(this._searchTypeId);
             this._searchTypeId = 0;
         }
 
         if (this._searchMatchId != 0) {
-            Global.searchMatchManager.disconnect(this._searchMatchId);
+            Application.searchMatchManager.disconnect(this._searchMatchId);
             this._searchMatchId = 0;
         }
 
         if (this._collectionId != 0) {
-            Global.collectionManager.disconnect(this._collectionId);
+            Application.collectionManager.disconnect(this._collectionId);
             this._collectionId = 0;
         }
 
@@ -647,12 +427,9 @@ const OverviewSearchbar = new Lang.Class({
     hide: function() {
         this._dropdownButton.set_active(false);
 
-        // clear all the search properties when hiding the entry
-        this._searchEntry.set_text('');
-
-        Global.searchTypeManager.setActiveItemById('all');
-        Global.searchMatchManager.setActiveItemById('all');
-        Global.sourceManager.setActiveItemById('all');
+        Application.searchTypeManager.setActiveItemById('all');
+        Application.searchMatchManager.setActiveItemById('all');
+        Application.sourceManager.setActiveItemById('all');
 
         this.parent();
     }
